@@ -1,7 +1,7 @@
 package Regexp::Pattern::YouTube;
 
-our $DATE = '2016-09-12'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2016-09-13'; # DATE
+our $VERSION = '0.002'; # VERSION
 
 our %RE = (
     video_id => { pat => qr/[A-Za-z0-9_-]{11}/ },
@@ -22,7 +22,24 @@ Regexp::Pattern::YouTube - Regexp patterns related to YouTube
 
 =head1 VERSION
 
-This document describes version 0.001 of Regexp::Pattern::YouTube (from Perl distribution Regexp-Pattern-YouTube), released on 2016-09-12.
+This document describes version 0.002 of Regexp::Pattern::YouTube (from Perl distribution Regexp-Pattern-YouTube), released on 2016-09-13.
+
+=head1 SYNOPSIS
+
+ use Regexp::Pattern; # exports re()
+ my $re = re("YouTube::video_id");
+
+=head1 DESCRIPTION
+
+L<Regexp::Pattern> is a convention for organizing reusable regex patterns.
+
+=head1 PATTERNS
+
+=over
+
+=item * video_id
+
+=back
 
 =head1 HOMEPAGE
 
